function AttenGUI(bvals,dvals)
%AttenGUI(b_in,bvals,dvals) GUI interface script for attenuation relationships
%   Kevin Mackie, 2002/07/26
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   INPUT: bvals name corresponding to each design parameter
%		   dvals default design parameter value
%
%   Spawns appropriate functions for viewing attenuation plots
%	Makes the relationship given coefficients as:
%		eg. for 1 bent bridge
% 		ln(EDP)=A+Bln(IM)+C*LoH+D*DcDs+E*rhos+F*L+G*wt+H*ksoil+I*fy+J*fc+K*rhot+L*skew

load AttenGUI;

% set up window and axes
a = figure('Color',[0.8 0.8 0.8], ...
	'Colormap',mat0, ...
	'Position',[43 227 691 490], ...
	'Tag','Fig2');
b = axes('Parent',a, ...
	'Units','points', ...
	'CameraUpVector',[0 1 0], ...
	'Color',[1 1 1], ...
	'ColorOrder',mat1, ...
	'Position',[209 40 465 412], ...
	'Tag','Axes2', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);
c = text('Parent',b, ...
	'Color',[0 0 0], ...
	'HandleVisibility','callback', ...
	'HorizontalAlignment','center', ...
	'Position',[0.498922 -0.0377129 0], ...
	'Tag','Text1', ...
	'VerticalAlignment','cap');
set(get(c,'Parent'),'XLabel',c);
c = text('Parent',b, ...
	'Color',[0 0 0], ...
	'HandleVisibility','callback', ...
	'HorizontalAlignment','center', ...
	'Position',[-0.0484914 0.5 0], ...
	'Rotation',90, ...
	'Tag','Text2', ...
	'VerticalAlignment','baseline');
set(get(c,'Parent'),'YLabel',c);
c = text('Parent',b, ...
	'Color',[0 0 0], ...
	'HandleVisibility','callback', ...
	'HorizontalAlignment','right', ...
	'Position',[-0.451509 1.09367 0], ...
	'Tag','Text3', ...
	'Visible','off');
set(get(c,'Parent'),'ZLabel',c);
c = text('Parent',b, ...
	'Color',[0 0 0], ...
	'HandleVisibility','callback', ...
	'HorizontalAlignment','center', ...
	'Position',[0.498922 1.01338 0], ...
	'Tag','Text4', ...
	'VerticalAlignment','bottom');
set(get(c,'Parent'),'Title',c);

% Dynamic text fields
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Position',[13 419 77 15], ...
	'String',bvals{1}, ...
	'Style','text', ...
	'Tag','DynamicText1');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Position',[13 394 77 15], ...
	'String',bvals{2}, ...
	'Style','text', ...
	'Tag','DynamicText2');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Position',[13 369 77 15], ...
	'String',bvals{3}, ...
	'Style','text', ...
	'Tag','DynamicText3');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Position',[13 344 77 15], ...
	'String',bvals{4}, ...
	'Style','text', ...
	'Tag','DynamicText4');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Position',[13 319 77 15], ...
	'String',bvals{5}, ...
	'Style','text', ...
	'Tag','DynamicText5');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Position',[13 294 77 15], ...
	'String',bvals{6}, ...
	'Style','text', ...
	'Tag','DynamicText6');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Position',[13 269 77 15], ...
	'String',bvals{7}, ...
	'Style','text', ...
	'Tag','DynamicText7');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Position',[13 244 77 15], ...
	'String',bvals{8}, ...
	'Style','text', ...
	'Tag','DynamicText8');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Position',[13 219 77 15], ...
	'String',bvals{9}, ...
	'Style','text', ...
	'Tag','DynamicText9');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Position',[13 194 77 15], ...
	'String',bvals{10}, ...
	'Style','text', ...
	'Tag','DynamicText10');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Position',[13 142 77 15], ...
	'String','IM max', ...
	'Style','text', ...
	'Tag','DynamicText11');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'Position',[13 117 77 15], ...
	'String','EDP max', ...
	'Style','text', ...
	'Tag','DynamicText12');
	
% edit text fields
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[99 416.5 68 20], ...
	'String',dvals(1), ...
	'Style','edit', ...
	'Tag','EditText1');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[99 391.5 68 20], ...
	'String',dvals(2), ...
	'Style','edit', ...
	'Tag','EditText2');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[99 366.5 68 20], ...
	'String',dvals(3), ...
	'Style','edit', ...
	'Tag','EditText3');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[99 341.5 68 20], ...
	'String',dvals(4), ...
	'Style','edit', ...
	'Tag','EditText4');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[99 316.5 68 20], ...
	'String',dvals(5), ...
	'Style','edit', ...
	'Tag','EditText5');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[99 291.5 68 20], ...
	'String',dvals(6), ...
	'Style','edit', ...
	'Tag','EditText6');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[99 266.5 68 20], ...
	'String',dvals(7), ...
	'Style','edit', ...
	'Tag','EditText7');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[99 241.5 68 20], ...
	'String',dvals(8), ...
	'Style','edit', ...
	'Tag','EditText8');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[99 216.5 68 20], ...
	'String',dvals(9), ...
	'Style','edit', ...
	'Tag','EditText9');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[99 191.5 68 20], ...
	'String',dvals(10), ...
	'Style','edit', ...
	'Tag','EditText10');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[99 139.5 68 20], ...
	'String','1', ...
	'Style','edit', ...
	'Tag','EditText11');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Position',[99 114.5 68 20], ...
	'String','1', ...
	'Style','edit', ...
	'Tag','EditText12');
	
% Static text fields
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'FontSize',11, ...
	'Position',[248 461 299 18], ...
	'String','Demand Model Attenuation Interface', ...
	'Style','text', ...
	'Tag','StaticText1');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[24 445 151 15], ...
	'String','Design Parameter Values', ...
	'Style','text', ...
	'Tag','StaticText2');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[24 168 151 15], ...
	'String','IM-EDP Extents', ...
	'Style','text', ...
	'Tag','StaticText3');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[5 472 225 12], ...
	'FontSize',8, ...
	'String','Kevin Mackie, 2002, University of California Berkeley', ...
	'Style','text', ...
	'Tag','StaticText6');

% push-buttons and controls
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','PlotAtten', ...
	'Position',[28 85 60 22], ...
	'String','PLOT', ...
	'Tag','Pushbutton1');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','MakePrintable', ...
	'Position',[103 85 60 22], ...
	'String','Print', ...
	'Tag','Pushbutton2');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','cla', ...
	'Position',[28 55 60 22], ...
	'String','Clear', ...
	'Tag','Pushbutton3');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','zoom', ...
	'Position',[103 55 60 22], ...
	'String','Zoom', ...
	'Tag','Pushbutton4');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','close', ...
	'Position',[65.5 25 60 22], ...
	'String','Return', ...
	'Tag','Pushbutton5');
