function GUIsetup(T1)
%GUIsetup() GUI interface script for all models
%   Kevin Mackie, 2002/01/26
%   University of California Berkeley
%   Department of Civil and Environmental Engineering
%   mackie@ce.berkeley.edu
%
%   INPUT: T1 menu of Parameter values for given bridge
%
%   Spawns appropriate functions for viewing IM DM plots

global XAX;
global YAX;
global TYP;
global GRP;
global FIT;
global SIG;
global MODEL;
global DEQ;
global SUMLOC;

global NVALS;
global IM_ARR;
global DM_ARR;

load PlotWin;

% computer type
comptype=computer;

% figure window and axes ----------------------------------------------
if strcmp(comptype,'PCWIN')==1,
a = figure('Color',[0.8 0.8 0.8], ...
	'Colormap',mat0, ...
	'Position',[40 30 800 700], ...
	'Tag','Fig1');
else
a = figure('Color',[0.8 0.8 0.8], ...
	'Colormap',mat0, ...
	'Position',[40 580 600 525], ...
	'Tag','Fig1');
end;

b = axes('Parent',a, ...
	'Units','points', ...
	'CameraUpVector',[0 1 0], ...
	'Color',[1 1 1], ...
	'ColorOrder',mat1, ...
	'Position',[130 95 450 395], ...
	'Tag','Axes1', ...
	'XColor',[0 0 0], ...
	'YColor',[0 0 0], ...
	'ZColor',[0 0 0]);
c = text('Parent',b, ...
	'Color',[0 0 0], ...
	'HandleVisibility','callback', ...
	'HorizontalAlignment','center', ...
	'Position',[0.5 -0.0527211 0], ...
	'Tag','Text1', ...
	'VerticalAlignment','cap');
set(get(c,'Parent'),'XLabel',c);
c = text('Parent',b, ...
	'Color',[0 0 0], ...
	'HandleVisibility','callback', ...
	'HorizontalAlignment','center', ...
	'Position',[-0.0648415 0.501701 0], ...
	'Rotation',90, ...
	'Tag','Text2', ...
	'VerticalAlignment','baseline');
set(get(c,'Parent'),'YLabel',c);
c = text('Parent',b, ...
	'Color',[0 0 0], ...
	'HandleVisibility','callback', ...
	'HorizontalAlignment','right', ...
	'Position',[-0.309798 1.10714 0], ...
	'Tag','Text3');
set(get(c,'Parent'),'ZLabel',c);
c = text('Parent',b, ...
	'Color',[0 0 0], ...
	'HandleVisibility','callback', ...
	'HorizontalAlignment','center', ...
	'Position',[0.5 1.01871 0], ...
	'Tag','Text4', ...
	'VerticalAlignment','bottom');
set(get(c,'Parent'),'Title',c);

% Y-axis IM menus ----------------------------------------------
IM1=NVALS(IM_ARR(:,2),:);
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','menucom(3)', ...
	'FontSize',9, ...
	'Position',[140 0 200 36], ...
	'String',IM1, ...
	'Style','popupmenu', ...
	'Tag','IMMenu', ...
	'Value',20);

% X-axis DM menus ----------------------------------------------
DM1=NVALS(DM_ARR(:,2),:);
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','menucom(4)', ...
	'FontSize',9, ...
	'Position',[375 0 200 36], ...
	'String',DM1, ...
	'Style','popupmenu', ...
	'Tag','DMMenu', ...
	'Value',4);

% pop up menus ----------------------------------------------
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','menucom(1)', ...
	'FontSize',9, ...
	'Position',[13 0 100 36], ...
	'String',T1, ...
	'Style','popupmenu', ...
	'Tag','PopupMenu1', ...
	'Value',GRP);

if MODEL==1,
T2=['Parameters      ';'Seismicity      '; ...
    'Typical IDA     ';'M Dependence    ';'R Dependence    '; ...
	'Duration Depend ';'Vector IM 3D    ';'Demand Hazard   '; ...
	'Demand Fragility'];
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','menucom(2)', ...
	'FontSize',9, ...
	'Position',[13 45 100 36], ...
	'String',T2, ...
	'Style','popupmenu', ...
	'Tag','PopupMenu2', ...
	'Value',TYP);
else
T2=['Parameters      ';'Seismicity      '; ...
    'Bin Dependence  ';'M Dependence    ';'R Dependence    '; ...
	'Duration Depend ';'Vector IM 3D    ';'Demand Hazard   '; ...
	'Demand Fragility'];
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','menucom(2)', ...
	'FontSize',9, ...
	'Position',[13 45 100 36], ...
	'String',T2, ...
	'Style','popupmenu', ...
	'Tag','PopupMenu2', ...
	'Value',TYP);
end;

T3=['Log      ';'Linear   ';'Semilog x';'Semilog y'];
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','menucom(5)', ...
	'FontSize',9, ...
	'Position',[13 305 70 36], ...
	'String',T3, ...
	'Style','popupmenu', ...
	'Tag','PopupMenu3', ...
	'Value',1);
	
T4=['Linear  ';'Bilinear'];
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','menucom(6)', ...
	'FontSize',9, ...
	'Position',[13 265 70 36], ...
	'String',T4, ...
	'Style','popupmenu', ...
	'Tag','PopupMenu4', ...
	'Value',FIT);
	
T5=['Mean     ';'Mean+84th'];
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','menucom(7)', ...
	'FontSize',9, ...
	'Position',[13 225 70 36], ...
	'String',T5, ...
	'Style','popupmenu', ...
	'Tag','PopupMenu5', ...
	'Value',SIG);
	
T6=['On ';'Off'];
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','menucom(8)', ...
	'FontSize',9, ...
	'Position',[13 185 70 36], ...
	'String',T6, ...
	'Style','popupmenu', ...
	'Tag','PopupMenu6', ...
	'Value',DEQ);
	
% Other window features (buttons) ----------------------------------------------
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','GeneratePlot', ...
	'FontSize',9, ...
	'Position',[13 420 70 20], ...
	'String','PLOT', ...
	'Tag','PB1');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','zoom', ...
	'FontSize',9, ...
	'Position',[13 395 70 20], ...
	'String','Zoom', ...
	'Tag','PB2');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','MakePrintable', ...
	'FontSize',9, ...
	'Position',[13 370 70 20], ...
	'String','Print', ...
	'Tag','PB3');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','SavePlot', ...
	'FontSize',9, ...
	'Position',[13 170 70 20], ...
	'String','Save Plot', ...
	'Tag','PB4');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','GenerateAtten', ...
	'FontSize',9, ...
	'Position',[13 145 70 20], ...
	'String','Attenuate', ...
	'Tag','PB6');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Callback','Demand', ...
	'FontSize',9, ...
	'Position',[13 120 70 20], ...
	'String','Return', ...
	'Tag','PB5');

% Text fields ----------------------------------------------
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[165 40 150 15], ...
	'String','Select Intensity Measure...', ...
	'Style','text', ...
	'Tag','StaticText1');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[400 40 150 15], ...
	'String','Select Damage Measure...', ...
	'Style','text', ...
	'Tag','StaticText2');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[18 85 90 15], ...
	'String','Plot Type...', ...
	'Style','text', ...
	'Tag','StaticText3');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[18 40 90 15], ...
	'String','Parameter...', ...
	'Style','text', ...
	'Tag','StaticText4');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[5 510 225 12], ...
	'FontSize',8, ...
	'String','Kevin Mackie, 2002, University of California Berkeley', ...
	'Style','text', ...
	'Tag','StaticText5');

if MODEL==1,
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[200 0 260 18], ...
	'FontSize',11, ...
	'String','Incremental Dynamic Analysis PSDMs', ...
	'HorizontalAlignment','center', ...
	'Style','text', ...
	'Tag','StaticText6');
else
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[200 0 260 18], ...
	'FontSize',11, ...
	'String','Probabilistic Seismic Demand Analysis PSDMs', ...
	'HorizontalAlignment','center', ...
	'Style','text', ...
	'Tag','StaticText6');
end;

b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[13 345 70 12], ...
	'FontSize',9, ...
	'String','Axis scale', ...
	'Style','text', ...
	'Tag','StaticText7');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[13 305 70 12], ...
	'FontSize',9, ...
	'String','Fit type', ...
	'Style','text', ...
	'Tag','StaticText8');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[13 265 70 12], ...
	'FontSize',9, ...
	'String','Fit lines', ...
	'Style','text', ...
	'Tag','StaticText9');
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[13 225 70 12], ...
	'FontSize',9, ...
	'String','Design eqns', ...
	'Style','text', ...
	'Tag','StaticText10');

% add identifying tag for currently selected bridge type
switch SUMLOC
   case 'no_abut_1',
      bstring='1 bent, no abutment bridge';
   case 'no_abut_2',
      bstring='2 bent, no abutment bridge';
   case 'no_abut_3',
      bstring='3 bent, no abutment bridge';
   case 'abut_1',
      bstring='1 bent with abutment bridge';
   case 'abut_2',
      bstring='2 bent with abutment bridge';
   case 'abut_3',
      bstring='3 bent with abutment bridge';
   case 'ncee_abut',
      bstring='1 bent with abutment NCEE';
   case 'nsc_abut',
      bstring='1 bent with abutment NSC';
   case 'combo',
      bstring='Bent comparisons';
   otherwise
      bstring='Invalid bridge type in GUIsetup';
end;
b = uicontrol('Parent',a, ...
	'Units','points', ...
	'BackgroundColor',[0.733333 0.733333 0.733333], ...
	'Position',[13 445 70 40], ...
	'FontName','Times New Roman', ...
	'FontSize',11, ...
	'String',bstring, ...
	'Style','text', ...
	'Tag','StaticText11');
